@@ -37,6 +37,16 @@ def test_format_value3():
     print(format_value('255', 'bit(v, 2)'))
     print(format_value('2', '_or(bit(v, 1), bit(v, 0), _and(bit(v, 0),bit(v, 1)))'))
 
+def test_format_value31():
+    a = format_value(str(int(0x7B)), 'bit(v, 0)*2+bit(v, 1)')
+    print(format_value('255', 'bit(v, 0)'))
+    print(format_value('255', 'bit(v, 1)'))
+    print(format_value('255', 'bit(v, 2)'))
+    print(format_value(str(int(0x7B)), '_or(bit(v, 1), bit(v, 0), _and(bit(v, 0),bit(v, 1)))'))
+
+    datas = bytes([0x7B])
+    freq_ant = int(format_value(str(int(datas[0])), 'bit(v, 0)') + format_value(str(int(datas[0])), 'bit(v, 1)'))
+    print(freq_ant)
 
 def test_nvn_value():
     result = format_value('952', '(max(4, v*3.3*1000/(4095*150))-4)/16*100', 3)
@@ -51,4 +61,4 @@ def test_conver():
     print(format_value(str(result), '(max(4, v*3.3*1000/(4095*150))-4)/16*100', 3))
     print()
 
-test_conver()
\ No newline at end of file
+test_format_value31()
\ No newline at end of file
